###Marcelo A. Aizen, Gabriela R. Gleiser, Thomas Kitzberger, Ruben Milla. 
###Being a tree crop increases the odds of experiencing yield declines 
###irrespective of pollinator dependence.

########################################################################################
# Script to run all the analyses. Version 4.0.2 of R is needed to run the phylo models#
# Author: M.A. Aizen                                                                  #
#######################################################################################

options(max.print = 99999)
#Loading required datasets

data=read.csv("growth.csv", sep=",", header=T) #dataset that includes growth rates estimates
phylonames=read.csv("phylonames.csv", sep=",", header=T) #dataset with the equivalences between common crop names and names in the crop phylogeny
data=merge(data, phylonames, by.x = "crop", by.y = "crop")

library(ape)  #library to read and prune phylogenetic trees
phylo137=read.tree("phylo137.tre")  #phylogenetic crop tree
length(phylo137$tip.label)
phylo137=drop.tip(phylo137, c("peppermint"))  #excluding peppermint because it is not in the final dataset
length(phylo137$tip.label)

#######Chisqr tests of associations between pollinator dependence and growth form###############

#For all crops
xx=data.frame(data$crop, data$form, data$dep)
xx=unique(xx)
names(xx)=c("crop", "form", "dep")
table(xx$dep)
table(xx$form)
xx=table(xx$dep, xx$form)
chisq.test(xx, correct=TRUE)
(xx=apply(xx,2,function(x) 100*x/sum(x)))

#Restricted to crops cultivated for their reproductive parts
datar=data[data$organ=="reproductive",]
xx=data.frame(datar$crop, datar$form, datar$dep)
xx=unique(xx)
names(xx)=c("crop", "form", "dep")
table(xx$dep)
table(xx$form)
(xx=table(xx$dep, xx$form))
chisq.test(xx, correct=TRUE)
(xx=apply(xx,2,function(x) 100*x/sum(x)))


##############################################
#Preparing data, and loading packages and functions for the mixed model analyses 
#described in the text


data$slope_bin=ifelse(data$slope<0, 1, 0) #Converting yield growth into a binary variable
                                          #decline 1 non-decline 0
data$lareac=log10(data$areac)-mean(log10(data$areac))  #log transfomation and centering of cumulative cultivated area per crop
data$lareap=log10(data$areap)-mean(log10(data$areap))  #log transfomation and centering of cumulative cultivated area per country

#Required packages
library(glmmTMB)
library(lme4)      # general linear mixed models
library(car)
library(plyr)
library(phytools)
library(geiger)
library(sjPlot)
library(lsmeans)
library(arm)

## Function "phylo_glmm" to conduct phylogenetic mixed model analyses 
source("lme4_phylo_setup.R")
phyloZ = phylo.to.Z(phylo137)  #converting phylogenetic tree into a matrix format

#Function to verify phylogenetic patterning in the residuals
phylo_sig=function(data, phylo137){
  new_db_2=ddply(data, .(crop_phylo),summarize,mean_2=mean(res_2), se_2=sd(res_2)/sqrt(length(res_2)))
  ## names in database and tip names should exactly match
  new_db_2=new_db_2[match(phylo137$tip.label,new_db_2$crop_phylo),]
  head(phylo137$tip.label, n=10)
  head(new_db_2, n=20)
  name.check(phylo137, new_db_2, data.names=new_db_2$crop) ## OK!
  mean_2=new_db_2$mean_2
  se_2=new_db_2$se_2
  names(mean_2)=new_db_2$crop_phylo
  names(se_2)=new_db_2$crop_phylo
  (signal_K_2=phylosig(phylo137,mean_2,method="K", test=TRUE, nsim=10000))
}


########################################################################################################
###############Mixed linear models described in the paper (results summarized in Table S1)#################

#options(contrasts=c("contr.sum","contr.poly"))  ## needed for correct conditional SS

##################################################################################
#GLMM_0

glmm_0=glmmTMB(slope_bin  ~   1 +  (1|country) + (1|crop), data=data,family=binomial(link="logit"))
summary(glmm_0)
confint(glmm_0)
tab_model(glmm_0)  #this function provides marginal and conditional R2

#Phylogenetic pattern of the residuals
data$res_2=residuals(glmm_0)
phylo_sig(data, phylo137)

#Rechecking results with the glmer function
glmm_0_bis=glmer(slope_bin ~ 1 +  (1|country) + (1|crop), data=data,  family=binomial)  
summary(glmm_0_bis)


#Equivalent phylogenetic model
glmm_0_phylo= phylo_glmm(slope_bin ~  1 + (1|crop_phylo) + (1|country)
                         , data=data
                         , phylonm = "crop_phylo"
                         , family = binomial
                         , phylo = phylo137
                         , phyloZ=phyloZ
                         , control=lmerControl(check.nobs.vs.nlev="ignore",check.nobs.vs.nRE="ignore"))
summary(glmm_0_phylo)


AIC(glmm_0, glmm_0_bis, glmm_0_phylo)  #comparing the three models


##################################################################################
#GLMM_1a

glmm_1a=glmmTMB(slope_bin  ~   dep + region +   lareap + lareac  +  (1|country) + (1|crop), data=data,family=binomial(link="logit"))
summary(glmm_1a)
Anova(glmm_1a)
confint(glmm_1a)
tab_model(glmm_1a)  #this function provides marginal and conditional R2


#Phylogenetic pattern of the residuals
data$res_2=residuals(glmm_1a)
phylo_sig(data, phylo137)

#Rechecking results with the glmer function
glmm_1a_bis=glmer(slope_bin ~ dep + region +   lareap + lareac  +  (1|country) + (1|crop), data=data,  family=binomial)  
summary(glmm_1a_bis)
Anova(glmm_1a_bis)
vif(glmm_1a_bis)  #vif function works with glmer but not with glmmTMB

#Equivalent phylogenetic model
glmm_1a_phylo= phylo_glmm(slope_bin ~  dep + region +   lareap + lareac  + (1|crop_phylo) + (1|country)
                         , data=data
                         , phylonm = "crop_phylo"
                         , family = binomial
                         , phylo = phylo137
                         , phyloZ=phyloZ
                         , control=lmerControl(check.nobs.vs.nlev="ignore",check.nobs.vs.nRE="ignore"))
summary(glmm_1a_phylo)
Anova(glmm_1a_phylo)

AIC(glmm_1a, glmm_1a_bis, glmm_1a_phylo)  #comparing the three models


##################################################################################
#GLMM_1b

glmm_1b=glmmTMB(slope_bin  ~   form + region +   lareap + lareac  +  (1|country) + (1|crop), data=data,family=binomial(link="logit"))
summary(glmm_1b)
Anova(glmm_1b)
confint(glmm_1b)
tab_model(glmm_1b)  #this function provides marginal and conditional R2

#Phylogenetic pattern of the residuals as estimated by the K of Blomberg
data$res_2=residuals(glmm_1b)
phylo_sig(data, phylo137)

#Rechecking results with the glmer function
glmm_1b_bis=glmer(slope_bin ~ form + region +   lareap + lareac  +  (1|country) + (1|crop), data=data,  family=binomial)  
summary(glmm_1b_bis)
Anova(glmm_1b_bis)
vif(glmm_1b_bis)  #vif function works with glmer but not with glmmTMB

#Equivalent phylogenetic model
glmm_1b_phylo= phylo_glmm(slope_bin ~  form + region +   lareap + lareac  + (1|crop_phylo) + (1|country)
                          , data=data
                          , phylonm = "crop_phylo"
                          , family = binomial
                          , phylo = phylo137
                          , phyloZ=phyloZ
                          , control=lmerControl(check.nobs.vs.nlev="ignore",check.nobs.vs.nRE="ignore"))
summary(glmm_1b_phylo)
Anova(glmm_1b_phylo)

AIC(glmm_1b, glmm_1b_bis, glmm_1b_phylo)  #comparing the three models


##################################################################################
#GLMM_2

glmm_2=glmmTMB(slope_bin  ~  dep +  form + region + lareap + lareac  +  (1|country) + (1|crop), data=data,family=binomial(link="logit"))
summary(glmm_2)
Anova(glmm_2)
confint(glmm_2)
tab_model(glmm_2)  #this function provides marginal and conditional R2

#Phylogenetic pattern of the residuals as estimated by the K of Blomberg
data$res_2=residuals(glmm_2)
phylo_sig(data, phylo137)

#Rechecking results with the glmer function
glmm_2_bis=glmer(slope_bin ~ dep + form + region +lareap + lareac  +  (1|country) + (1|crop), data=data,  family=binomial)  
summary(glmm_2_bis)
Anova(glmm_2_bis)  
vif(glmm_2_bis)  #vif function works with glmer but not with glmmTMB


#Equivalent phylogenetic model
glmm_2_phylo= phylo_glmm(slope_bin ~ dep +  form + region + lareap + lareac  + (1|crop_phylo) + (1|country)
                          , data=data
                          , phylonm = "crop_phylo"
                          , family = binomial
                          , phylo = phylo137
                          , phyloZ=phyloZ
                          , control=lmerControl(check.nobs.vs.nlev="ignore",check.nobs.vs.nRE="ignore"))
summary(glmm_2_phylo)
Anova(glmm_2_phylo)

AIC(glmm_2, glmm_2_bis, glmm_2_phylo)  #comparing the three models


##################################################################################
#GLMM_3

glmm_3=glmmTMB(slope_bin  ~  dep*form + dep*region +form*region  +   lareap + lareac  +  (1|country) + (1|crop), data=data,family=binomial(link="logit"))
summary(glmm_3)
Anova(glmm_3)
confint(glmm_3)
tab_model(glmm_3)  #this function provides marginal and conditional R2

#Phylogenetic pattern of the residuals as estimated by the K of Blomberg
data$res_3=residuals(glmm_3)
phylo_sig(data, phylo137)

#Rechecking results with the glmer function
glmm_3_bis=glmer(slope_bin ~ dep*form + dep*region +form*region  +   lareap + lareac  +  (1|country) + (1|crop), data=data,  family=binomial)  
summary(glmm_3_bis)
Anova(glmm_3_bis)

#Equivalent phylogenetic model
glmm_3_phylo= phylo_glmm(slope_bin ~ dep*form + dep*region +form*region + region +   lareap + lareac  + (1|crop_phylo) + (1|country)
                         , data=data
                         , phylonm = "crop_phylo"
                         , family = binomial
                         , phylo = phylo137
                         , phyloZ=phyloZ
                         , control=lmerControl(check.nobs.vs.nlev="ignore",check.nobs.vs.nRE="ignore"))
summary(glmm_3_phylo)
Anova(glmm_3_phylo)

AIC(glmm_3, glmm_3_bis, glmm_3_phylo)  #comparing the three models

####################################################################################################################
#Testing for the effect of harvested organ....
mod_organ=glmmTMB(slope_bin  ~   organ+   lareap + lareac  +  (1|country) + (1|crop),
          data=data[data$dep=="none",],family=binomial(link="logit"))#  family=list(family="beta",link="logit"))
summary(mod_organ)
Anova(mod_organ)
confint(mod_organ)^2
tab_model(mod_organ)

meansxx<-lsmeans(mod_organ, ~ organ)
(meansxx=summary(meansxx))
(means.es=invlogit(meansxx[,2]))
(means.lo=invlogit(meansxx[,2]-meansxx[,3]))
(means.hi=invlogit(meansxx[,2]+meansxx[,3]))


