###Marcelo A. Aizen, Gabriela R. Gleiser, Thomas Kitzberger, Ruben Milla. 
###Being a tree crop increases the odds of experiencing yield declines 
###irrespective of pollinator dependence. 

#############################################################
#Construction of the dataset that includes all the variables#
#to be analyzed in a single dataset and estimation of growth # 
#rates.                                                      #
# Author: M.A. Aizen                                         #
#############################################################

#############The synthesis dataset##########################

# Set options
options(max.print = 99999)

## Loading data files
# Loading the FAO datase
data_basic = read.csv("FAOdata_21-12-2021.csv", sep = ",", header = T)[c(2, 4, 6, 8, 10)]
  names(data_basic) = c("country", "crop", "vari", "year", "value")
  data_basic = data_basic[data_basic$country != "China", ]   #Delete China because reported series are since 1991
  data_basic$country[data_basic$country == "China, mainland"] = "China"  #"China, mainland"  includes the complete series

# Loading the country dataset
countries = data.frame(read.csv("countries.csv", sep = ",", header = T)[, c(1, 2)])
  names(countries)=c("country", "region")  
  
# Loading the pollinator dependence dataset
dependence = read.csv("dependence.csv", sep = ",", header = T)

# Loading the traits dataset (others than pollinator dependence)
traits = data.frame(read.csv("traits.csv", sep = ",", header = T)[, c(1, 5, 6)])
  names(traits)=c("crop", "organ", "form")


# Merging datasets
data_basic = merge(data_basic, countries, by.x = "country", by.y = "country")
data_basic = merge(data_basic, dependence, by.x = "crop", by.y = "crop")
data_basic = merge(data_basic, traits, by.x = "crop", by.y = "crop")


#Changing the format of the dataset from "long" to "wide" according to the variable reported by FAO (i.e., area, production, and yield)
library(reshape)
data=reshape(data_basic, direction="wide", timevar="vari",
                   idvar=c("country", "region", "crop", "organ", "dep",  "form",  "year")) 

data=data[, c(2,4, 1, 5, 7, 6, 3, 8, 10, 9)]
names(data)=c("country","region","crop", "dep", "form","organ","year", 
              "yield","prod","area")    #production in tonnes, area in hectares, yield in hectograms/ha
data$dep=ifelse(data$dep==3 | data$dep==4, "high", ifelse(data$dep==0,"none", "moderate"))  # grouping pollinator dependences in three clases
data$dep<- factor(data$dep, levels = c( "none", "moderate", "high"))

#Excluding incomplete or 0 records
data=data[order(data$country, data$crop, data$year), ]
data=na.omit(data)
data=data[data$area>0,] #excluding records with area=0 
data=data[data$prod>0,] #excluding records with production=0 
data=data[data$yield>0,] #excluding records with yield=0 
nrow(data)


#Excluding incomplete data series (not encompassing the entire period 1961-2020)  
no_years=aggregate(data$yield, list(data$crop, data$country), length)
names(no_years)=c("crop", "country", "years")
data=merge(data, no_years, by.x = c("crop", "country"), by.y = c("crop", "country")) 
nrow(data)
data=data[data$years==60,]
data=data[,1:10]  #drop the colum years
rownames(data)=1:nrow(data)
data =data[!apply(is.na(data) | data == "", 1, all),]
nrow(data)

data=data[order(data$country, data$crop, data$year), ]
write.csv(data, file="dataset.csv")  #this is the polished dataset

#################The growth dataset##############################

split_data = split(data, list(data$country, data$crop))
length(split_data)
split_data=split_data[sapply(split_data, nrow)==60] 
length(split_data)
split_data=na.omit(split_data)
length(split_data)

country=array(NA,length(split_data))   #vector of countries
region=array(NA,length(split_data))    #vector of regions or continents
crop=array(NA,length(split_data))      #vector of crops
dep=array(NA,length(split_data))       #vector of pollinator dependencies
form=array(NA,length(split_data))      #vector of growth forms
organ=array(NA,length(split_data))     #vector of harvested organs
min_year=array(NA,length(split_data))  #vector of the first year of the time series
max_year=array(NA,length(split_data))  #vector of the last year of the time series
no_year=array(NA,length(split_data))   #vector of number of years of the time series
lyigr=array(NA,length(split_data))     #vector of yield growth estimated as mean difference of (natural) logarithms of yearly yield
slope=array(NA,length(split_data))     #vector of yield growth estimated as the slope of the relation between the (natural) log of yield and year
year_maxyi=array(NA,length(split_data))   #vector of year of maximum yield
area=array(NA,length(split_data))         #vector of total accumulative harvested area in squared kilometers
slopea=array(NA,length(split_data))       #vector of cultivated area growth estimated as mean difference of (natural) logarithms of yearly harvested area
yield_range=array(NA,length(split_data)) #vector of differences between maximum and minimum (log10) yield 

#Construction of the growth dataset
for (i in 1:length(split_data)) {
  x=split_data[[i]]
  country[i]=as.character(x$country[1]) #country
  region[i]=as.character(x$region[1]) #continent 
  crop[i]=as.character(x$crop[1]) #crop name
  dep[i]=as.character(x$dep[1])  #pollinator dependence
  form[i]=as.character(x$form[1])  #growth form
  organ[i]=as.character(x$organ[1]) #harvested organ
  min_year[i]=min(x$year) #first year of the time series
  max_year[i]=max(x$year) #last year of the time series
  no_year[i]=max(x$year)-min(x$year)+1   #number of years of the time series
  lyigr[i]=mean(diff(log(x$yield)))  #yield growth estimated as mean difference of (natural) logarithms of yearly yield
  x$lyield=log(x$yield)
  slope[i]= coef(lm(lyield~year, data=x ))[2]  #yield growth estimated as the slope of the relation between the (natural) log of yield vs year
  yield_range[i]=log10(max(x$yield))-log10(min(x$yield))  #vector of differences between maximum and minimum (log10) yield 
  year_maxyi[i]=x$year[x$yield==max(x$yield)]   #year of maximum yield
  area[i]=sum(x$area)/100  #total accumulative harvested area in square kilometers
  slopea[i]=coef(lm(log(x$area)~x$year ))[2]   #vector of cultivated area growth estimated as mean difference of (natural) logarithms of yearly harvested areaa
}

data_growth=data.frame(country, region, crop, dep,  form, organ, min_year, max_year, no_year, 
                      lyigr,  slope,  yield_range, year_maxyi, area, slopea)

names(data_growth)=c("country","region","crop", "dep" , "form", "organ", "year_ini", "year_end", "num_year",
                    "log_growth", "slope","yield_range", "year_max", "area", "slopea")
nrow(data_growth)
data_growth=data_growth[data_growth$num_year==60,]  #Rechecking that growth estimates is based on complete time series
nrow(data_growth)
data_growth=data_growth[data_growth$yield_range<=2, ]  #Discarding all growth estimates where yields differed by two or more orders of magnitude between any two years
nrow(data_growth)

length(unique(data_growth$country))  #number of countries included in the growth dataset
length(unique(data_growth$crop))     #number of crops included in the growth dataset

x=aggregate(data$area, list(data$crop), sum)  # total area cultivated per crop
names(x)=c("crop", "areac")
data_growth=merge(data_growth, x, by.x = "crop", by.y = "crop")
nrow(data_growth)

x=aggregate(data$area, list(data$country), sum) # total area cultivated per country
names(x)=c("country", "areap")
data_growth=merge(data_growth, x, by.x = "country", by.y = "country")
nrow(data_growth)

c(min(data_growth$slope), max(data_growth$slope))

cor.test(data_growth$slope, data_growth$log_growth)  #correlation between yield growth estimates base on the slope and mean differences in log yield 
cor.test(data_growth$slope, data_growth$year_max)    #correlation between yield growth estimates based on the slope and and the year of max yield
cor.test(data_growth$slope, data_growth$slopea)     #correlation between yield and area growth estimates based on the slope

data_growth=data_growth[order(data_growth$country, data_growth$crop), ]
write.csv(data_growth, file="growth.csv")  #the polished growth dataset

###############################################################




